@@ -172,7 +172,25 @@ def build(extension, publish=False, config=None):
         "activationEvents": activation_events,
     }
     if extension.keybindings:
-        package_config["contributes"].update({'keybindings':extension.keybindings})
+        package_config["contributes"].update({"keybindings": extension.keybindings})
+
+    if extension.activity_bar:
+        package_config["contributes"]["viewsContainers"] = {
+            "activitybar": [extension.activity_bar]
+        }
+        view = {
+            extension.activity_bar["id"]: [
+                {
+                    "id": extension.activity_bar["id"],
+                    "name": extension.activity_bar["title"],
+                }
+            ]
+        }
+        if package_config["contributes"].has_key("views"):
+            package_config["contributes"]["views"].update(view)
+        else:
+            package_config["contributes"]["views"] = view
+
     package = create_package(ext_data, package_config)
     javascript = build_js(package_name, ext_data["events"], ext_data["commands"])
     python = build_py([c.func for c in ext_data["commands"]])
