@@ -8,6 +8,7 @@ class Extension:
         self.events = {}
         self.default_category = None
         self.keybindings = []
+        self.activity_bar = None
 
     def register_command(
         self, func, name=None, title=None, category=None, keybind=None, when=None
@@ -40,6 +41,16 @@ class Extension:
     def set_default_category(self, category):
         self.default_category = category
 
+    def set_activity_bar(self, activity_bar):
+        if isinstance(activity_bar, ActivityBar):
+            self.activity_bar = activity_bar.__dict__
+        elif isinstance(activity_bar, dict):
+            self.activity_bar = activity_bar
+        else:
+            raise TypeError(
+                "activity_bar must be either an instance of vscode.ActivityBar or dict"
+            )
+
 
 class Command:
     def __init__(self, name, func, title=None, category=None, keybind=None, when=None):
@@ -84,3 +95,10 @@ class Command:
 
     def __repr__(self):
         return f"<vscode.Command {self.name}>"
+
+
+class ActivityBar:
+    def __init__(self, id, title, icon):
+        self.id = id
+        self.title = title
+        self.icon = icon
